KeyCode

Enum KeyCode 

pub enum KeyCode {
Show 82 variants A, B, C, D, E, F, G, H, I, J, K, L, M, N, O, P, Q, R, S, T, U, V, W, X, Y, Z, Digit0, Digit1, Digit2, Digit3, Digit4, Digit5, Digit6, Digit7, Digit8, Digit9, F1, F2, F3, F4, F5, F6, F7, F8, F9, F10, F11, F12, ArrowUp, ArrowDown, ArrowLeft, ArrowRight, Home, End, PageUp, PageDown, Backspace, Delete, Enter, Tab, Space, Escape, ShiftLeft, ShiftRight, ControlLeft, ControlRight, AltLeft, AltRight, MetaLeft, MetaRight, Minus, Equal, BracketLeft, BracketRight, Backslash, Semicolon, Quote, Comma, Period, Slash, Backquote, Unknown,
}
Re-export the UI crate so applications can depend on a single crate. Physical key codes for keyboard input.

These represent physical keys on the keyboard, independent of the character they produce (which depends on keyboard layout).

Variants



A



B



C



D



E



F



G



H



I



J



K



L



M



N



O



P



Q



R



S



T



U



V



W



X



Y



Z



Digit0



Digit1



Digit2



Digit3



Digit4



Digit5



Digit6



Digit7



Digit8



Digit9



F1



F2



F3



F4



F5



F6



F7



F8



F9



F10



F11



F12



ArrowUp



ArrowDown



ArrowLeft



ArrowRight



Home



End



PageUp



PageDown



Backspace



Delete



Enter



Tab



Space



Escape



ShiftLeft



ShiftRight



ControlLeft



ControlRight



AltLeft



AltRight



MetaLeft



MetaRight



Minus



Equal



BracketLeft



BracketRight



Backslash



Semicolon



Quote



Comma



Period



Slash



Backquote



Unknown

Key not recognized or not mapped.

Implementations

Source

impl KeyCode

pub fn from_dom_code(code: &str) -> KeyCode

The key a W3C KeyboardEvent.code value names, such as "KeyA", "ArrowUp" or "ShiftLeft"; "NumpadEnter" is KeyCode::Enter. A code with no counterpart here is KeyCode::Unknown.