pub enum LaunchError {
EventLoopCreate(EventLoopError),
WindowCreate(RequestError),
SurfaceCreate(CreateSurfaceError),
NoSurfaceFormat,
NoSurfaceAlphaMode,
NoAdapter(RequestAdapterError),
DeviceCreate(RequestDeviceError),
GpuContextUnavailable,
ContentUnavailable,
EventLoopRun(EventLoopError),
}Expand description
Errors that can occur while launching a windowed (desktop or iOS) application.
Variants
EventLoopCreate(EventLoopError)
Creating the desktop event loop failed.
WindowCreate(RequestError)
Creating the desktop window failed.
SurfaceCreate(CreateSurfaceError)
Creating the rendering surface failed.
NoSurfaceFormat
The rendering surface did not report any supported formats.
NoSurfaceAlphaMode
The rendering surface did not report any supported alpha modes.
NoAdapter(RequestAdapterError)
No compatible GPU adapter was available for the surface.
DeviceCreate(RequestDeviceError)
Creating the GPU device failed.
The desktop renderer context was not initialized before a surface needed it.
The application content closure was already consumed before the primary shell was created.
EventLoopRun(EventLoopError)
The desktop event loop terminated with an error.