pub enum PaintLayer {
Behind,
Content,
Overlay,
}Expand description
Re-export the UI crate so applications can depend on a single crate. Layer that a paint operation targets within the rendering pipeline.
Variants