pub enum PreferencesError {
Io(String),
Unavailable,
}Expand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Errors produced by a preferences backend.
Variants
Io(String)
The backing store could not be read or written.
No durable storage is available on this platform or build.