pub fn BoxWithConstraints<F>(__arg0: Modifier, __arg1: F) -> usizewhere
F: FnMut(BoxWithConstraintsScopeImpl) + 'static,Expand description
Re-export the UI crate so applications can depend on a single crate.
pub fn BoxWithConstraints<F>(__arg0: Modifier, __arg1: F) -> usizewhere
F: FnMut(BoxWithConstraintsScopeImpl) + 'static,Re-export the UI crate so applications can depend on a single crate.