pub fn WindowGroup(
__arg0: &'static str,
__arg1: WindowAttachPolicy,
content: impl FnMut() + 'static,
)Expand description
Applies attachment and move policy to all peer windows declared inside it.
pub fn WindowGroup(
__arg0: &'static str,
__arg1: WindowAttachPolicy,
content: impl FnMut() + 'static,
)Applies attachment and move policy to all peer windows declared inside it.