pub fn clear_platform_camera()Expand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Removes the platform camera and forgets everything the last session published.
pub fn clear_platform_camera()Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Removes the platform camera and forgets everything the last session published.