pub fn current_lifecycle_state() -> LifecycleStateExpand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Returns the latest lifecycle state published by the platform host.
pub fn current_lifecycle_state() -> LifecycleStateRe-export framework services (HTTP, URI, etc.) from the dedicated services crate. Returns the latest lifecycle state published by the platform host.