pub fn current_native_window_surface_origin() -> Option<Point>Expand description
Returns the desktop-space origin of the current native window surface while dispatching input inside a native window.
This is None for inline content and outside native-window input dispatch.