format_layout_tree

Function format_layout_tree 

pub fn format_layout_tree(layout: &LayoutTree) -> String
Re-export the UI crate so applications can depend on a single crate. Returns a formatted string representation of the layout tree