format_render_scene

Function format_render_scene 

pub fn format_render_scene(scene: &RecordedRenderScene) -> String
Re-export the UI crate so applications can depend on a single crate. Returns a formatted string representation of the render scene