pub fn get_cursor_x_for_offset(
text: &AnnotatedString,
style: &TextStyle,
offset: usize,
) -> f32Expand description
Re-export the UI crate so applications can depend on a single crate.
pub fn get_cursor_x_for_offset(
text: &AnnotatedString,
style: &TextStyle,
offset: usize,
) -> f32Re-export the UI crate so applications can depend on a single crate.