pub fn host_surface() -> Arc<dyn HostSurface> ⓘExpand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. The installed host surface, or one that accepts no resize requests.
pub fn host_surface() -> Arc<dyn HostSurface> ⓘRe-export framework services (HTTP, URI, etc.) from the dedicated services crate. The installed host surface, or one that accepts no resize requests.