pub fn layout_text(
text: &AnnotatedString,
style: &TextStyle,
) -> TextLayoutResultExpand description
Re-export the UI crate so applications can depend on a single crate.
pub fn layout_text(
text: &AnnotatedString,
style: &TextStyle,
) -> TextLayoutResultRe-export the UI crate so applications can depend on a single crate.