pub fn log_screen_summary(layout: &LayoutTree, scene: &RecordedRenderScene)Expand description
Re-export the UI crate so applications can depend on a single crate. Logs a compact summary of what’s on screen (counts by type).
pub fn log_screen_summary(layout: &LayoutTree, scene: &RecordedRenderScene)Re-export the UI crate so applications can depend on a single crate. Logs a compact summary of what’s on screen (counts by type).