pub fn network_monitor() -> Rc<dyn NetworkMonitor>Expand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. The active network monitor: the platform one if installed, else the default (online, unmetered).
pub fn network_monitor() -> Rc<dyn NetworkMonitor>Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. The active network monitor: the platform one if installed, else the default (online, unmetered).