pub fn remember_svg(bytes: &'static [u8]) -> Result<SvgPainter, SvgPainterError>Expand description
Re-export the UI crate so applications can depend on a single crate.
pub fn remember_svg(bytes: &'static [u8]) -> Result<SvgPainter, SvgPainterError>Re-export the UI crate so applications can depend on a single crate.