pub fn request_render_invalidation()Expand description
Re-export the UI crate so applications can depend on a single crate. Requests that the renderer rebuild the current scene.
pub fn request_render_invalidation()Re-export the UI crate so applications can depend on a single crate. Requests that the renderer rebuild the current scene.