pub fn run_test_composition(build: impl FnMut()) -> TestCompositionExpand description
Re-export the UI crate so applications can depend on a single crate. Build a composition with a simple in-memory applier and run the provided closure once.
pub fn run_test_composition(build: impl FnMut()) -> TestCompositionRe-export the UI crate so applications can depend on a single crate. Build a composition with a simple in-memory applier and run the provided closure once.