pub fn set_platform_network_monitor(monitor: Arc<dyn NetworkMonitor>)Expand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Installs a platform network monitor, replacing any previous one.
pub fn set_platform_network_monitor(monitor: Arc<dyn NetworkMonitor>)Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Installs a platform network monitor, replacing any previous one.