pub fn set_platform_preferences(store: Arc<dyn PreferencesStore>)Expand description
Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Installs the platform preferences backend, replacing any previous one.
pub fn set_platform_preferences(store: Arc<dyn PreferencesStore>)Re-export framework services (HTTP, URI, etc.) from the dedicated services crate. Installs the platform preferences backend, replacing any previous one.