take_pointer_invalidation

Function take_pointer_invalidation 

pub fn take_pointer_invalidation() -> bool
Re-export the UI crate so applications can depend on a single crate. Returns true if a pointer invalidation was pending and clears the flag.