pub fn window_insets() -> WindowInsetsExpand description
Re-export the UI crate so applications can depend on a single crate. Returns the framework-owned insets currently visible to the composition.
pub fn window_insets() -> WindowInsetsRe-export the UI crate so applications can depend on a single crate. Returns the framework-owned insets currently visible to the composition.