CrossAxisAlignment

Enum CrossAxisAlignment 

pub enum CrossAxisAlignment {
    Start,
    Center,
    End,
}
Cross-axis alignment for flex layouts. This is axis-agnostic and gets interpreted based on the flex axis.

Variants



Start

Align to the start of the cross axis (Top for Row, Start for Column)



Center

Align to the center of the cross axis



End

Align to the end of the cross axis (Bottom for Row, End for Column)