pub struct Announcement {
pub text: String,
pub mode: LiveRegionMode,
}Expand description
Re-export the UI crate so applications can depend on a single crate. Text a screen reader should read out, with no control to move to.
Fields
text: Stringmode: LiveRegionModeTrait Implementations
Sourceimpl Clone for Announcement
impl Clone for Announcement
Sourcefn clone(&self) -> Announcement
fn clone(&self) -> Announcement
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Announcement
impl Debug for Announcement
impl Eq for Announcement
Sourceimpl PartialEq for Announcement
impl PartialEq for Announcement
impl StructuralPartialEq for Announcement