pub struct FocusEntry {
pub node_id: usize,
pub rect: Rect,
}Expand description
Re-export the UI crate so applications can depend on a single crate. One focus target, with the bounds layout gave it.
Fields
node_id: usizerect: RectImplementations