LayoutBox

Struct LayoutBox 

pub struct LayoutBox {
    pub node_id: usize,
    pub node_generation: u32,
    pub rect: Rect,
    pub content_offset: Point,
    pub node_data: LayoutNodeData,
    pub children: Vec<LayoutBox>,
}
Re-export the UI crate so applications can depend on a single crate. Layout information for a single node.

Fields

node_id: usizenode_generation: u32

Incarnation of the runtime node captured with these layout bounds.

rect: Rectcontent_offset: Point

Content offset for scroll/inner transforms (applies to children, NOT this node’s position)

node_data: LayoutNodeDatachildren: Vec<LayoutBox>

Implementations

Source

impl LayoutBox

pub fn new( node_id: usize, rect: Rect, content_offset: Point, node_data: LayoutNodeData, children: Vec<LayoutBox>, ) -> LayoutBox