pub struct LayoutNodeData {
pub modifier: Modifier,
pub resolved_modifiers: ResolvedModifiers,
pub modifier_slices: Rc<ModifierNodeSlices>,
pub semantics: Option<Rc<SemanticsConfiguration>>,
pub kind: LayoutNodeKind,
}Expand description
Re-export the UI crate so applications can depend on a single crate. Snapshot of the data required to render a layout node.
Fields
modifier: Modifierresolved_modifiers: ResolvedModifiersmodifier_slices: Rc<ModifierNodeSlices>semantics: Option<Rc<SemanticsConfiguration>>kind: LayoutNodeKindImplementations
Sourceimpl LayoutNodeData
impl LayoutNodeData
pub fn new( modifier: Modifier, resolved_modifiers: ResolvedModifiers, modifier_slices: Rc<ModifierNodeSlices>, semantics: Option<Rc<SemanticsConfiguration>>, kind: LayoutNodeKind, ) -> LayoutNodeData
Sourcepub fn semantics(&self) -> Option<&SemanticsConfiguration>
pub fn semantics(&self) -> Option<&SemanticsConfiguration>
Semantics the node’s live modifier chain reported when the snapshot was taken.
pub fn resolved_modifiers(&self) -> ResolvedModifiers
pub fn modifier_slices(&self) -> &ModifierNodeSlices