pub struct LazyListItemInfo {
pub index: usize,
pub key: u64,
pub offset: f32,
pub size: f32,
}Expand description
Re-export the UI crate so applications can depend on a single crate. Information about a single visible item in a lazy list.
Fields
index: usizeIndex of the item in the data source.
key: u64Key of the item.
offset: f32Offset of the item from the start of the list content.
size: f32Size of the item in the main axis.