pub struct ModifierChainTraceGuard { /* private fields */ }Expand description
Re-export the UI crate so applications can depend on a single crate. RAII guard returned when installing a modifier chain trace subscriber.