OffsetNode

Struct OffsetNode 

pub struct OffsetNode { /* private fields */ }
Re-export the UI crate so applications can depend on a single crate. Node that offsets its content by a fixed (x, y) amount.

Matches Kotlin: OffsetNode in foundation-layout/src/commonMain/kotlin/androidx/compose/foundation/layout/Offset.kt

Implementations

Source

impl OffsetNode

pub fn new(x: f32, y: f32, rtl_aware: bool) -> OffsetNode

pub fn offset(&self) -> Point

pub fn rtl_aware(&self) -> bool