pub struct RecordedRenderScene { /* private fields */ }Expand description
Re-export the UI crate so applications can depend on a single crate. A collection of render operations for a composed scene.
Implementations
Sourceimpl RecordedRenderScene
impl RecordedRenderScene
pub fn new(operations: Vec<RenderOp>) -> RecordedRenderScene
Sourcepub fn operations(&self) -> &[RenderOp]
pub fn operations(&self) -> &[RenderOp]
Returns a slice of recorded render operations in submission order.
Sourcepub fn primitives_for(
&self,
layer: PaintLayer,
) -> impl Iterator<Item = &DrawPrimitive>
pub fn primitives_for( &self, layer: PaintLayer, ) -> impl Iterator<Item = &DrawPrimitive>
Returns an iterator over primitives that target the provided paint layer.