pub struct SliderScope { /* private fields */ }Expand description
Re-export the UI crate so applications can depend on a single crate. Values available to custom slider track and thumb content.
Implementations
Sourceimpl SliderScope
impl SliderScope
Sourcepub fn track_extent(&self) -> f32
pub fn track_extent(&self) -> f32
Main-axis space through which the thumb can travel.
Sourcepub fn thumb_offset(&self) -> f32
pub fn thumb_offset(&self) -> f32
Main-axis offset for the leading edge of the thumb.
Sourcepub fn is_dragging(&self) -> bool
pub fn is_dragging(&self) -> bool
Whether direct pointer input is currently changing the value.
Sourcepub fn interaction_source(&self) -> MutableInteractionSource
pub fn interaction_source(&self) -> MutableInteractionSource
Interaction source shared by the slider surface.