pub struct TextFieldElement { /* private fields */ }Expand description
Re-export the UI crate so applications can depend on a single crate.
Element that creates and updates TextFieldModifierNode instances.
This follows the modifier element pattern where the element is responsible for:
- Creating new nodes (via
create) - Updating existing nodes when properties change (via
update) - Declaring capabilities (LAYOUT | DRAW | SEMANTICS)
Implementations
Sourceimpl TextFieldElement
impl TextFieldElement
Sourcepub fn new(state: TextFieldState, style: TextStyle) -> TextFieldElement
pub fn new(state: TextFieldState, style: TextStyle) -> TextFieldElement
Creates a new text field element.
Sourcepub fn with_cursor_color(self, color: Color) -> TextFieldElement
pub fn with_cursor_color(self, color: Color) -> TextFieldElement
Creates an element with custom cursor color.
Sourcepub fn with_line_limits(
self,
line_limits: TextFieldLineLimits,
) -> TextFieldElement
pub fn with_line_limits( self, line_limits: TextFieldLineLimits, ) -> TextFieldElement
Creates an element with custom line limits.
Sourcepub fn with_handle_controller(
self,
controller: TextFieldHandleController,
) -> TextFieldElement
pub fn with_handle_controller( self, controller: TextFieldHandleController, ) -> TextFieldElement
Installs the finger-handle metrics channel shared with the composable.
Sourcepub fn with_modal_depth(self, depth: usize) -> TextFieldElement
pub fn with_modal_depth(self, depth: usize) -> TextFieldElement
Sets the modal depth this field was composed at (see
crate::modal::local_modal_depth).