pub struct TextModifierElement { /* private fields */ }Expand description
Re-export the UI crate so applications can depend on a single crate. Element that creates and updates TextModifierNode instances.
This follows the modifier element pattern where the element is responsible for:
- Creating new nodes (via
create) - Updating existing nodes when properties change (via
update) - Declaring capabilities (LAYOUT | DRAW | SEMANTICS)
Matches Jetpack Compose: TextStringSimpleElement in BasicText.kt
Implementations
Sourceimpl TextModifierElement
impl TextModifierElement
pub fn new( text: AnnotatedString, style: TextStyle, options: TextLayoutOptions, ) -> TextModifierElement