pub struct Builder { /* private fields */ }Expand description
A builder to construct AnnotatedString.
Implementations
Sourceimpl Builder
impl Builder
pub fn new() -> Builder
Sourcepub fn push_style(self, style: SpanStyle) -> Builder
pub fn push_style(self, style: SpanStyle) -> Builder
Applies the given SpanStyle to any appended text until a corresponding pop is called.
Returns the index of the pushed style, which can be passed to pop_to or used as an ID.
Sourcepub fn push_paragraph_style(self, style: ParagraphStyle) -> Builder
pub fn push_paragraph_style(self, style: ParagraphStyle) -> Builder
Applies the given ParagraphStyle to any appended text until a corresponding pop is called.
Sourcepub fn push_string_annotation(self, tag: &str, annotation: &str) -> Builder
pub fn push_string_annotation(self, tag: &str, annotation: &str) -> Builder
Pushes a string annotation covering subsequent appended text until the matching pop.
JC parity: Builder.pushStringAnnotation(tag, annotation)
Sourcepub fn push_link(self, link: LinkAnnotation) -> Builder
pub fn push_link(self, link: LinkAnnotation) -> Builder
Pushes a LinkAnnotation covering subsequent appended text.
Call [pop] when done, or use [with_link] for the block form.
JC parity: Builder.pushLink(link)
Sourcepub fn with_link(
self,
link: LinkAnnotation,
block: impl FnOnce(Builder) -> Builder,
) -> Builder
pub fn with_link( self, link: LinkAnnotation, block: impl FnOnce(Builder) -> Builder, ) -> Builder
Sourcepub fn to_annotated_string(self) -> AnnotatedString
pub fn to_annotated_string(self) -> AnnotatedString
Completes the builder, resolving open styles to the end of the text.