pub trait BoxScope {
// Required method
fn align(&self, alignment: Alignment) -> Modifier;
}Expand description
Re-export the UI crate so applications can depend on a single crate.
Marker trait matching Jetpack Compose’s BoxScope API.
Future API - methods will be enabled as alignment modifiers are implemented.