pub fn Image<P>(
__arg0: P,
__arg1: Option<String>,
__arg2: Modifier,
__arg3: Alignment,
__arg4: ContentScale,
__arg5: f32,
__arg6: Option<ColorFilter>,
) -> usizeExpand description
Re-export the UI crate so applications can depend on a single crate. Displays a painter with an optional accessible description.
Images use the image accessibility role unless modifier supplies another role.
Without a description or modifier semantics, the image is decorative.