pub fn LazyRow<F>(
modifier: Modifier,
state: LazyListState,
spec: LazyRowSpec,
content: F,
) -> usizewhere
F: FnOnce(&mut LazyListIntervalContent),Expand description
Re-export the UI crate so applications can depend on a single crate. A horizontally scrolling list that only composes visible items.
Matches Jetpack Compose’s LazyRow API. The closure receives
a LazyListIntervalContent which implements LazyListScope for defining items.
Example
ⓘ
let state = rememberLazyListState();
LazyRow(Modifier::empty(), state, LazyRowSpec::default(), |scope| {
scope.items(10, |i| {
Text(format!("Item {}", i), Modifier::empty());
});
});