pub fn Spacer(__arg0: Size) -> usizeExpand description
Re-export the UI crate so applications can depend on a single crate. A component that represents an empty space.
When to use
Use Spacer to create empty space between other composables, or to push
composables apart when using weighted arrangements in Row or Column.
Arguments
size- The explicit size of the spacer.
Example
ⓘ
Row(..., || {
Text("Left", Modifier::empty());
Spacer(Size::new(16.0, 0.0)); // 16dp gap
Text("Right", Modifier::empty());
});