pub fn format_layout_tree(layout: &LayoutTree) -> StringExpand description
Re-export the UI crate so applications can depend on a single crate. Returns a formatted string representation of the layout tree
pub fn format_layout_tree(layout: &LayoutTree) -> StringRe-export the UI crate so applications can depend on a single crate. Returns a formatted string representation of the layout tree