pub fn format_render_scene(scene: &RecordedRenderScene) -> StringExpand description
Re-export the UI crate so applications can depend on a single crate. Returns a formatted string representation of the render scene
pub fn format_render_scene(scene: &RecordedRenderScene) -> StringRe-export the UI crate so applications can depend on a single crate. Returns a formatted string representation of the render scene