pub struct LayoutBox {
pub node_id: usize,
pub node_generation: u32,
pub rect: Rect,
pub content_offset: Point,
pub node_data: LayoutNodeData,
pub children: Vec<LayoutBox>,
}Expand description
Re-export the UI crate so applications can depend on a single crate. Layout information for a single node.
Fields
node_id: usizenode_generation: u32Incarnation of the runtime node captured with these layout bounds.
rect: Rectcontent_offset: PointContent offset for scroll/inner transforms (applies to children, NOT this node’s position)
node_data: LayoutNodeDatachildren: Vec<LayoutBox>Implementations