Re-export the UI crate so applications can depend on a single crate. UI Widget components
Modules
- basic_
text_ field - BasicTextField widget for editable text input.
- box_
widget - Box widget implementation
- button
- Button widget implementation
- canvas
- Canvas composable for custom drawing via
DrawScope. - clickable_
text - ClickableText widget for handling clicks on annotated text.
- column
- Column widget implementation
- foreach
- ForEach iteration helper
- image
- Image composable and painter primitives.
- layout
- Generic Layout widget and SubcomposeLayout
- lazy_
list - LazyColumn and LazyRow widget implementations.
- linked_
text - LinkedText widget — renders AnnotatedString with link annotations auto-handled.
- nodes
- row
- Row widget implementation
- scopes
- Scope traits and implementations for Box, Column, and Row
- spacer
- Spacer widget implementation
- text
- Text widget implementation
Structs
- Basic
Text Field Options - Options for customizing BasicTextField appearance and behavior.
- BoxScope
Impl - Concrete implementation of BoxScope.
- BoxSpec
- Specification for Box layout behavior.
- BoxWith
Constraints Scope Impl - Concrete implementation of
BoxWithConstraintsScope. - Button
Spec - Column
Scope Impl - Concrete implementation of ColumnScope.
- Column
Spec - Specification for Column layout behavior.
- Dynamic
Text Source - Layout
Node - Layout
State - Retained layout state for a LayoutNode. This mirrors Jetpack Compose’s approach where each node stores its own measured size and placed position, eliminating the need for per-frame LayoutTree reconstruction.
- Lazy
Column Spec - Specification for LazyColumn layout behavior.
- Lazy
List Item Info - Information about a single visible item in a lazy list.
- Lazy
List Layout Info - Information about the currently visible items in a lazy list.
- Lazy
RowSpec - Specification for LazyRow layout behavior.
- Painter
- RowScope
Impl - Concrete implementation of RowScope.
- RowSpec
- Specification for Row layout behavior.
- SvgPainter
- Parsed SVG image data that rasterizes on demand for the requested draw size.
Enums
- Content
Scale - Intrinsic
Kind - SvgPainter
Error - Errors returned while parsing or rasterizing an SVG painter.
- Text
Constants
Traits
- BoxScope
- Marker trait matching Jetpack Compose’s
BoxScopeAPI. - BoxWith
Constraints Scope - Scope exposed to [
BoxWithConstraints] content. - Column
Scope - Marker trait for Column scope - provides horizontal alignment.
- RowScope
- Marker trait for Row scope - provides vertical alignment.
Functions
- Basic
Text - Basic
Text Field - When to use
- Basic
Text Field With Options - Creates an editable text field with custom options.
- Basic
Text With Options - Bitmap
Painter - Box
- A layout composable that stacks its children on top of each other.
- BoxWith
Constraints - Button
- A clickable button with a background and content.
- Canvas
- A composable that draws custom content using a
DrawScope. - Clickable
Text - Displays an
AnnotatedStringand callson_clickwith the byte offset of the character under the pointer at the time of the click. - Column
- A layout composable that places its children in a vertical sequence.
- ForEach
- Image
- Layout
- Lazy
Column - A vertically scrolling list that only composes visible items.
- LazyRow
- A horizontally scrolling list that only composes visible items.
- Linked
Text - Renders an
AnnotatedStringand automatically dispatches link clicks: - Row
- A layout composable that places its children in a horizontal sequence.
- Spacer
- A component that represents an empty space.
- Subcompose
Layout - Text
- Text
With Options - cranpose_
node - remember_
svg